@@ -42,6 +42,7 @@
 #include <libempathy/empathy-time.h>
 #include <libempathy/empathy-utils.h>
 
+#include "empathy-calendar-button.h"
 #include "empathy-contact-widget.h"
 #include "empathy-contactinfo-utils.h"
 #include "empathy-account-chooser.h"
@@ -102,6 +103,7 @@ typedef struct
   GtkWidget *vbox_avatar;
   GtkWidget *favourite_checkbox;
   GtkWidget *label_details;
+  GtkWidget *label_left_account;
 
   /* Location */
   GtkWidget *vbox_location;
@@ -251,33 +253,30 @@ contact_widget_details_changed_cb (GtkEntry *entry,
 }
 
 static void
-contact_widget_bday_changed_cb (GtkCalendar *calendar,
+contact_widget_bday_changed_cb (EmpathyCalendarButton *button,
+    GDate *date,
     EmpathyContactWidget *self)
 {
-  guint year, month, day;
-  GDate *date;
-  gchar tmp[255];
   const gchar *strv[] = { NULL, NULL };
   TpContactInfoField *field;
 
   self->details_changed = TRUE;
 
-  field = g_object_get_data ((GObject *) calendar, DATA_FIELD);
+  field = g_object_get_data ((GObject *) button, DATA_FIELD);
   g_assert (field != NULL);
 
-  gtk_calendar_get_date (calendar, &year, &month, &day);
-  date = g_date_new_dmy (day, month+1, year);
+  if (date != NULL)
+    {
+      gchar tmp[255];
 
-  gtk_calendar_clear_marks (calendar);
-  gtk_calendar_mark_day (calendar, g_date_get_day (date));
+      g_date_strftime (tmp, sizeof (tmp), EMPATHY_DATE_FORMAT_DISPLAY_SHORT,
+          date);
+      strv[0] = tmp;
+    }
 
-  g_date_strftime (tmp, sizeof (tmp), EMPATHY_DATE_FORMAT_DISPLAY_SHORT, date);
-  strv[0] = tmp;
   if (field->field_value != NULL)
     g_strfreev (field->field_value);
   field->field_value = g_strdupv ((GStrv) strv);
-
-  g_date_free (date);
 }
 
 static void contact_widget_details_notify_cb (EmpathyContactWidget *information);
@@ -411,20 +410,25 @@ contact_widget_details_update_edit (EmpathyContactWidget *information)
 
       /* Add Title */
       title = empathy_contact_info_field_label (field->field_name,
-          field->parameters);
+          field->parameters,
+          (spec->flags & TP_CONTACT_INFO_FIELD_FLAG_PARAMETERS_EXACT));
       w = gtk_label_new (title);
       g_free (title);
 
+      /* TODO: if TP_CONTACT_INFO_FIELD_FLAG_PARAMETERS_EXACT is not set we
+       * should allow user to tag the vCard fields (bgo#672034) */
+
       gtk_grid_attach (GTK_GRID (information->grid_details),
           w, 0, n_rows, 1, 1);
 
-      gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
+      gtk_misc_set_alignment (GTK_MISC (w), 1, 0.5);
       gtk_widget_show (w);
 
       /* Add Value */
       if (!tp_strdiff (field->field_name, "bday"))
         {
-          w = gtk_calendar_new ();
+          w = empathy_calendar_button_new ();
+
           if (field->field_value[0])
             {
               GDate date;
@@ -432,24 +436,18 @@ contact_widget_details_update_edit (EmpathyContactWidget *information)
               g_date_set_parse (&date, field->field_value[0]);
               if (g_date_valid (&date))
                 {
-                  gtk_calendar_select_day (GTK_CALENDAR (w),
-                      g_date_get_day (&date));
-                  gtk_calendar_select_month (GTK_CALENDAR (w),
-                      g_date_get_month (&date) - 1, g_date_get_year (&date));
-                  gtk_calendar_mark_day (GTK_CALENDAR (w),
-                      g_date_get_day (&date));
+                  empathy_calendar_button_set_date (EMPATHY_CALENDAR_BUTTON (w),
+                      &date);
                 }
             }
 
           gtk_grid_attach (GTK_GRID (information->grid_details),
               w, 1, n_rows, 1, 1);
-          gtk_widget_show (w);
+          gtk_widget_show_all (w);
 
           g_object_set_data ((GObject *) w, DATA_FIELD, field);
 
-          g_signal_connect (w, "day-selected",
-            G_CALLBACK (contact_widget_bday_changed_cb), information);
-          g_signal_connect (w, "month-changed",
+          g_signal_connect (w, "date-changed",
             G_CALLBACK (contact_widget_bday_changed_cb), information);
         }
       else
@@ -536,7 +534,7 @@ contact_widget_details_update_show (EmpathyContactWidget *information)
 
       /* Add Title */
       title = empathy_contact_info_field_label (field->field_name,
-          field->parameters);
+          field->parameters, TRUE);
       title_widget = gtk_label_new (title);
       g_free (title);
 
@@ -1406,7 +1404,7 @@ contact_widget_contact_update (EmpathyContactWidget *information)
               contact_widget_change_contact, information);
         }
     }
-  else
+  else if ((information->flags & EMPATHY_CONTACT_WIDGET_NO_ACCOUNT) == 0)
     {
       if (account)
         {
@@ -1588,6 +1586,11 @@ contact_widget_contact_setup (EmpathyContactWidget *information)
             G_CALLBACK (contact_widget_change_contact),
             information);
     }
+  else if (information->flags & EMPATHY_CONTACT_WIDGET_NO_ACCOUNT)
+    {
+      /* Don't display the account */
+      gtk_widget_hide (information->label_left_account);
+    }
   else
     {
       /* Pack the protocol icon with the account name in an hbox */
@@ -1609,11 +1612,14 @@ contact_widget_contact_setup (EmpathyContactWidget *information)
           information->label_account, FALSE, TRUE, 0);
     }
 
-  gtk_grid_attach (GTK_GRID (information->grid_contact),
-      information->widget_account,
-      1, 0, 1, 1);
+  if (information->widget_account != NULL)
+    {
+      gtk_grid_attach (GTK_GRID (information->grid_contact),
+          information->widget_account,
+          1, 0, 1, 1);
 
-  gtk_widget_show (information->widget_account);
+      gtk_widget_show (information->widget_account);
+    }
 
   /* Set up avatar chooser/display */
   if (information->flags & EMPATHY_CONTACT_WIDGET_EDIT_AVATAR)
@@ -1764,6 +1770,7 @@ empathy_contact_widget_new (EmpathyContact *contact,
        "grid_client", &information->grid_client,
        "hbox_client_requested", &information->hbox_client_requested,
        "label_details", &information->label_details,
+       "label_left_account", &information->label_left_account,
        NULL);
   g_free (filename);
 
