@@ -64,6 +64,19 @@ empathy_gtk_init (void)
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
 					   PKGDATADIR G_DIR_SEPARATOR_S "icons");
 
+	/* Add icons from source dir if available */
+	if (g_getenv ("EMPATHY_SRCDIR") != NULL) {
+		gchar *path;
+
+		path = g_build_filename (g_getenv ("EMPATHY_SRCDIR"), "data",
+				"icons", "local-copy", NULL);
+		if (g_file_test (path, G_FILE_TEST_EXISTS)) {
+			gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (), path);
+		}
+
+		g_free (path);
+	}
+
 	initialized = TRUE;
 }
 
@@ -719,8 +732,8 @@ empathy_pixbuf_avatar_from_individual_scaled_async (
 	avatar_icon =
 		folks_avatar_details_get_avatar (FOLKS_AVATAR_DETAILS (individual));
 	if (avatar_icon == NULL) {
-		g_simple_async_result_set_error (result, TP_ERRORS,
-			TP_ERROR_INVALID_ARGUMENT, "no avatar found");
+		g_simple_async_result_set_error (result, G_IO_ERROR,
+			G_IO_ERROR_NOT_FOUND, "no avatar found");
 
 		g_simple_async_result_complete (result);
 		g_object_unref (result);
