@@ -277,6 +277,32 @@ install_haze_cb (GObject *source,
     }
 }
 
+static gboolean
+account_is_selected (EmpathyAccountsDialog *dialog,
+    TpAccount *account)
+{
+  EmpathyAccountsDialogPriv *priv = GET_PRIV (dialog);
+  GtkTreeSelection *selection;
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+  TpAccount *selected_account;
+
+  if (account == NULL)
+    return FALSE;
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
+
+  if (!gtk_tree_selection_get_selected (selection, &model, &iter))
+    return FALSE;
+
+  gtk_tree_model_get (model, &iter, COL_ACCOUNT, &selected_account, -1);
+
+  if (selected_account != NULL)
+    g_object_unref (selected_account);
+
+  return account == selected_account;
+}
+
 static void
 accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
     TpAccount *account)
@@ -286,28 +312,13 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
   guint                     status;
   guint                     reason;
   guint                     presence;
-  GtkTreeView               *view;
-  GtkTreeModel              *model;
-  GtkTreeSelection          *selection;
-  GtkTreeIter               iter;
-  TpAccount                 *selected_account;
   gboolean                  account_enabled;
   gboolean                  creating_account;
   TpStorageRestrictionFlags storage_restrictions = 0;
   gboolean display_switch = TRUE;
 
-  view = GTK_TREE_VIEW (priv->treeview);
-  selection = gtk_tree_view_get_selection (view);
-
-  if (!gtk_tree_selection_get_selected (selection, &model, &iter))
-    return;
-
-  gtk_tree_model_get (model, &iter, COL_ACCOUNT, &selected_account, -1);
-  if (selected_account != NULL)
-    g_object_unref (selected_account);
-
   /* do not update the infobar when the account is not selected */
-  if (account != selected_account)
+  if (!account_is_selected (dialog, account))
     return;
 
   if (account != NULL)
@@ -568,6 +579,8 @@ account_dialog_create_edit_params_dialog (EmpathyAccountsDialog *dialog)
   GtkWidget *subdialog, *content, *content_area, *align;
 
   settings = accounts_dialog_model_get_selected_settings (dialog);
+  if (settings == NULL)
+    return;
 
   subdialog = gtk_dialog_new_with_buttons (_("Edit Connection Parameters"),
       GTK_WINDOW (dialog),
@@ -701,6 +714,8 @@ account_dialow_show_edit_params_dialog (EmpathyAccountsDialog *dialog,
   TpStorageRestrictionFlags storage_restrictions;
 
   settings = accounts_dialog_model_get_selected_settings (dialog);
+  if (settings == NULL)
+    return;
 
   account = empathy_account_settings_get_account (settings);
   g_return_if_fail (account != NULL);
@@ -773,7 +788,8 @@ account_dialog_got_self_contact (TpConnection *conn,
       EMPATHY_CONTACT_WIDGET_EDIT_ALIAS |
       EMPATHY_CONTACT_WIDGET_EDIT_AVATAR |
       EMPATHY_CONTACT_WIDGET_NO_STATUS |
-      EMPATHY_CONTACT_WIDGET_EDIT_DETAILS);
+      EMPATHY_CONTACT_WIDGET_EDIT_DETAILS |
+      EMPATHY_CONTACT_WIDGET_NO_ACCOUNT);
 
   gtk_box_pack_start (GTK_BOX (priv->dialog_content), alig, TRUE, TRUE, 0);
   gtk_container_add (GTK_CONTAINER (alig), editor);
@@ -806,7 +822,8 @@ account_dialog_create_dialog_content (EmpathyAccountsDialog *dialog,
   if (account != NULL)
     conn = tp_account_get_connection (account);
 
-  if (conn != NULL)
+  if (conn != NULL &&
+      tp_proxy_get_invalidated (conn) == NULL)
     {
       empathy_tp_contact_factory_get_from_handle (conn,
           tp_connection_get_self_handle (conn),
@@ -1774,6 +1791,15 @@ finally:
   return FALSE;
 }
 
+static void
+reload_account_widget (EmpathyAccountsDialog *self)
+{
+  EmpathyAccountSettings *settings;
+
+  settings = accounts_dialog_model_get_selected_settings (self);
+  accounts_dialog_update_settings (self, settings);
+}
+
 static void
 accounts_dialog_connection_changed_cb (TpAccount *account,
     guint old_status,
@@ -1887,6 +1913,40 @@ accounts_dialog_account_display_name_changed_cb (TpAccount *account,
   g_object_unref (settings);
 }
 
+static void
+conn_prepare_cb (GObject *source,
+    GAsyncResult *result,
+    gpointer user_data)
+{
+  EmpathyAccountsDialog *self = user_data;
+
+  reload_account_widget (self);
+}
+
+static void
+accounts_dialog_notify_connection_cb (TpAccount *account,
+    GParamSpec *spec,
+    EmpathyAccountsDialog *self)
+{
+  TpConnection *conn;
+  if (!account_is_selected (self, account))
+    return;
+
+  conn = tp_account_get_connection (account);
+  if (conn == NULL)
+    {
+      reload_account_widget (self);
+    }
+  else
+    {
+      /* Wait for this feature so TpConnection will have fetch the
+       * self handle */
+      GQuark features[] = { TP_CONNECTION_FEATURE_CONNECTED, 0 };
+
+      tp_proxy_prepare_async (conn, features, conn_prepare_cb, self);
+    }
+}
+
 static void
 accounts_dialog_add_account (EmpathyAccountsDialog *dialog,
     TpAccount *account)
@@ -1952,6 +2012,8 @@ accounts_dialog_add_account (EmpathyAccountsDialog *dialog,
       G_CALLBACK (accounts_dialog_connection_changed_cb), dialog, 0);
   tp_g_signal_connect_object (account, "presence-changed",
       G_CALLBACK (accounts_dialog_presence_changed_cb), dialog, 0);
+  tp_g_signal_connect_object (account, "notify::connection",
+      G_CALLBACK (accounts_dialog_notify_connection_cb), dialog, 0);
 
   g_object_unref (settings);
 }
