@@ -119,7 +119,7 @@ new_call_handler_cb (EmpathyCallFactory *factory,
 
   DEBUG ("Show the call window");
 
-  g_object_get (handler, "target-contact", &contact, NULL);
+  contact = empathy_call_handler_get_contact (handler);
 
   window = g_hash_table_lookup (call_windows, contact);
 
@@ -217,7 +217,6 @@ main (int argc,
 
   g_option_context_free (optcontext);
 
-  gtk_clutter_init (&argc, &argv);
   clutter_gst_init (&argc, &argv);
 
   empathy_gtk_init ();
